@@ -6,6 +6,8 @@ from .bitmart.client import Client as BitmartClient
 from .gateio.client import Client as GateioClient
 from .hyperliquid.client import Client as HyperliquidClient
 from .bingx.client import Client as BingXClient
+from .kucoin.client import Client as KuCoinClient
+from .ascendex.client import Client as AscendexClient
 
 
 async def bybit(**kwargs):
@@ -56,6 +58,18 @@ async def bingx(**kwargs):
     await client.async_init()
     return client
 
+async def kucoin(**kwargs):
+    """Create and initialize a KuCoin client instance."""
+    client = KuCoinClient(**kwargs)
+    await client.async_init()
+    return client
+    
+async def ascendex(**kwargs):
+    """Create and initialize a AscendEX client instance."""
+    client = AscendexClient(**kwargs)
+    await client.async_init()
+    return client
+
 
 __all__ = [
     "bybit",
@@ -65,4 +79,6 @@ __all__ = [
     "gateio",
     "hyperliquid",
     "bingx",
+    "kucoin",
+    "ascendex",
 ]
