@@ -1,8 +1,14 @@
 from ._account_http import AccountHTTP
+from ._market_http import MarketHTTP
+from ._balance_http import BalanceHTTP
+from ._trade_http import TradeHTTP
 
 
 class Client(
     AccountHTTP,
+    MarketHTTP,
+    BalanceHTTP,
+    TradeHTTP,
 ):
     def __init__(self, **args):
         super().__init__(**args)
@@ -18,4 +24,4 @@ class Client(
         """Close the client and clean up resources."""
         if hasattr(self, "session") and self.session is not None:
             await self.session.aclose()
-            self.session = None 
\ No newline at end of file
+            self.session = None
