@@ -68,7 +68,7 @@ def format_product_symbol(symbol: str) -> str:
         base, quote = match.groups()
         return f"{base}-{quote}-SWAP"
 
-    quote_currencies = {"USDT", "USDC", "PERP", "USD"}
+    quote_currencies = {"USDT", "USDC", "PERP", "USD", "USD1"}
 
     matched_quote = next((quote for quote in quote_currencies if symbol.endswith(quote)), None)
 
@@ -137,7 +137,7 @@ async def bybit() -> pl.DataFrame:
     res_spot = await market_http.get_instruments_info(category="spot")
     df_spot = to_dataframe(res_spot["result"]["list"]) if "list" in res_spot.get("result", {}) else pl.DataFrame()
     for market in df_spot.iter_rows(named=True):
-        if not market["symbol"].endswith(("USDT", "USDC")):
+        if not market["symbol"].endswith(("USDT", "USDC", "USD", "USD1")):
             continue
         markets.append(
             MarketInfo(
@@ -196,7 +196,7 @@ async def okx() -> pl.DataFrame:
     res_spot = await public_http.get_public_instruments(instType="SPOT")
     df_spot = to_dataframe(res_spot["data"]) if "data" in res_spot else pl.DataFrame()
     for market in df_spot.iter_rows(named=True):
-        if not market["instId"].endswith(("USDT", "USDC", "USD")):
+        if not market["instId"].endswith(("USDT", "USDC", "USD", "USD1")):
             continue
         markets.append(
             MarketInfo(
@@ -250,7 +250,7 @@ async def bitmart() -> pl.DataFrame:
     await market_http.async_init()
 
     markets = []
-    quote_currencies = {"USDT", "USDC", "USD"}
+    quote_currencies = {"USDT", "USDC", "USD", "USD1"}
 
     res_swap = await market_http.get_contracts_details()
     df_swap = to_dataframe(res_swap.get("data", {}).get("symbols", []))
@@ -326,7 +326,7 @@ async def gateio() -> pl.DataFrame:
     await market_http.async_init()
 
     markets = []
-    quote_currencies = {"USDT", "USDC", "USD"}
+    quote_currencies = {"USDT", "USDC", "USD", "USD1"}
 
     res_futures = await market_http.get_all_futures_contracts()
     df_futures = to_dataframe(res_futures)
@@ -399,7 +399,7 @@ async def gateio() -> pl.DataFrame:
     res_spot = await market_http.get_spot_all_currency_pairs()
     df_spot = to_dataframe(res_spot)
     for market in df_spot.iter_rows(named=True):
-        if not market["id"].endswith(("USDT", "USDC", "USD")):
+        if not market["id"].endswith(("USDT", "USDC", "USD", "USD1")):
             continue
         markets.append(
             MarketInfo(
@@ -413,6 +413,7 @@ async def gateio() -> pl.DataFrame:
                 price_precision=reverse_decimal_places(market["precision"]),
                 size_precision=reverse_decimal_places(market["amount_precision"]),
                 min_size=market["min_base_amount"],
+                min_notional=market["min_quote_amount"],
             )
         )
 
@@ -427,12 +428,12 @@ async def binance() -> pl.DataFrame:
     await market_http.async_init()
 
     markets = []
-    quote_currencies = {"USDT", "USDC", "USD"}
+    quote_currencies = {"USDT", "USDC", "USD", "USD1"}
 
     res_spot = await market_http.get_spot_exchange_info()
     df_spot = to_dataframe(res_spot.get("symbols", []))
     for market in df_spot.iter_rows(named=True):
-        if not market["symbol"].endswith(("USDT", "USDC", "USD")):
+        if not market["symbol"].endswith(("USDT", "USDC", "USD", "USD1")):
             continue
 
         matched_quote = next(
@@ -466,7 +467,7 @@ async def binance() -> pl.DataFrame:
     res_futures = await market_http.get_futures_exchange_info()
     df_futures = to_dataframe(res_futures.get("symbols", []))
     for market in df_futures.iter_rows(named=True):
-        if not market["symbol"].endswith(("USDT", "USDC", "USD", "BUSD")):
+        if not market["symbol"].endswith(("USDT", "USDC", "USD", "BUSD", "USD1")):
             continue
 
         base = strip_number(market["baseAsset"])
@@ -569,14 +570,12 @@ async def bingx() -> pl.DataFrame:
 
     for market in df.iter_rows(named=True):
         symbol = market["symbol"]
-        if not symbol.endswith(("USDT", "USDC", "USD")):
+        if not symbol.endswith(("USDT", "USDC", "USD", "USD1")):
             continue
 
-        # 用 - 分割
         if "-" in symbol:
             base, quote = symbol.rsplit("-", 1)
         else:
-            # fallback，保險用
             if symbol.endswith("USDT"):
                 base = symbol[:-4]
                 quote = "USDT"
@@ -586,6 +585,9 @@ async def bingx() -> pl.DataFrame:
             elif symbol.endswith("USD"):
                 base = symbol[:-3]
                 quote = "USD"
+            elif symbol.endswith("USD1"):
+                base = symbol[:-4]
+                quote = "USD1"
             else:
                 continue
 
@@ -617,3 +619,83 @@ async def bingx() -> pl.DataFrame:
 
     markets = [market.to_dict() for market in markets]
     return pl.DataFrame(markets)
+
+async def kucoin() -> pl.DataFrame:
+    from ..kucoin._market_http import MarketHTTP
+
+    market_http = MarketHTTP()
+    await market_http.async_init()
+
+    markets = []
+    quote_currencies = {"USDT", "USDC", "USD", "USD1"}
+
+    res = await market_http.get_spot_instrument_info()
+    df = to_dataframe(res.get("data", []))
+
+    for market in df.iter_rows(named=True):
+        if not market["symbol"].endswith(("USDT", "USDC", "USD", "USD1")):
+            continue
+
+        matched_quote = next(
+            (quote for quote in quote_currencies if market["symbol"].endswith(quote)),
+            None,
+        )
+
+        if matched_quote:
+            product_symbol = clean_symbol(f"{market['baseCurrency']}-{market['quoteCurrency']}-SPOT")
+
+            markets.append(
+                MarketInfo(
+                    exchange=Common.KUCOIN,
+                    exchange_symbol=market["symbol"],
+                    product_symbol=product_symbol,
+                    product_type="spot",
+                    exchange_type="spot",
+                    base_currency=market["baseCurrency"],
+                    quote_currency=market["quoteCurrency"],
+                    price_precision=market["priceIncrement"],
+                    size_precision=market["baseIncrement"],
+                    min_size=market["baseMinSize"],
+                    min_notional=market["minFunds"] if market["minFunds"] else "0",
+                )
+            )
+          
+          
+    markets = [market.to_dict() for market in markets]
+    return pl.DataFrame(markets)
+
+async def ascendex() -> pl.DataFrame:
+    from ..ascendex._market_http import MarketHTTP
+
+    market_http = MarketHTTP()
+    await market_http.async_init()
+    markets = []
+    res = await market_http.get_spot_instrument_info()
+    data = res.get("data", [])
+    for market in data:
+        symbol = market.get("symbol", "")
+        if not (symbol.endswith("USDT") or symbol.endswith("USDC") or symbol.endswith("USD")):
+            continue
+
+        if "/" in symbol:
+            base, quote = symbol.split("/")
+        else:
+            continue
+        product_symbol = f"{base}-{quote}-SPOT"
+        markets.append(
+            MarketInfo(
+                exchange=Common.ASCENDEX,
+                exchange_symbol=symbol,
+                product_symbol=product_symbol,
+                product_type="spot",
+                exchange_type="spot",
+                base_currency=base,
+                quote_currency=quote,
+                price_precision=str(market.get("tickSize", "")),
+                size_precision=str(market.get("lotSize", "")),
+                min_size=str(market.get("minQty", "")),
+                min_notional=str(market.get("minNotional", "0")),
+            )
+        )
+    markets = [market.to_dict() for market in markets]
+    return pl.DataFrame(markets)
