@@ -1,7 +1,8 @@
 import asyncio
 import polars as pl
 from contextlib import asynccontextmanager
-from .fetch import bybit, okx, bitmart, gateio, binance, hyperliquid, bingx
+from .fetch import bybit, okx, bitmart, gateio, binance, hyperliquid, bingx, kucoin
+from .fetch import bybit, okx, bitmart, gateio, binance, hyperliquid, bingx, ascendex
 
 VALID_EXCHANGES = [
     bybit,
@@ -11,6 +12,8 @@ VALID_EXCHANGES = [
     binance,
     hyperliquid,
     bingx,
+    kucoin,
+    ascendex,
 ]
 
 
